#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：Shudaodao Auto Generator
# @Software ：PyCharm
# @Desc     ：SQLModel classes for shudaodao_meta.sys_enum_field

from datetime import datetime
from typing import Optional, TYPE_CHECKING

from sqlalchemy import BigInteger, Boolean

from shudaodao_core import SQLModel, BaseResponse, Field, Relationship, get_primary_id
from ...meta_config import MetaConfig

if TYPE_CHECKING:
    from .meta_schema import MetaSchema
    from .sys_enum_value import EnumValue


class EnumField(MetaConfig.RegistryModel, table=True):
    """数据库对象模型"""

    __tablename__ = "sys_enum_field"
    __table_args__ = {"schema": MetaConfig.SchemaTable, "comment": "枚举字段表"}
    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理

    field_id: int = Field(
        default_factory=get_primary_id, primary_key=True, sa_type=BigInteger, description="主键"
    )
    meta_schema_id: int = Field(
        foreign_key=f"{MetaConfig.SchemaForeignKey}meta_schema.meta_schema_id",
        sa_type=BigInteger,
        description="主键",
    )
    field_label: str = Field(max_length=50, description="字段标签")
    field_name: str = Field(max_length=50, description="字段列名")
    description: Optional[str] = Field(default=None, nullable=True, max_length=500, description="描述")
    is_active: bool = Field(sa_type=Boolean, description="启用状态")
    sort_order: int = Field(description="排序权重")
    create_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="创建人")
    create_at: Optional[datetime] = Field(default=None, nullable=True, description="创建日期")
    update_by: Optional[str] = Field(default=None, nullable=True, max_length=50, description="修改人")
    update_at: Optional[datetime] = Field(default=None, nullable=True, description="修改日期")
    tenant_id: Optional[int] = Field(default=None, sa_type=BigInteger, nullable=True, description="主键")
    # 反向关系 - 父对象
    MetaSchema: "MetaSchema" = Relationship(back_populates="EnumFields")
    # 正向关系 - 子对象
    EnumValues: list["EnumValue"] = Relationship(
        back_populates="EnumField", sa_relationship_kwargs={"order_by": "EnumValue.sort_order.asc()"}
    )


class EnumFieldCreate(SQLModel):
    """前端创建模型 - 用于接口请求"""

    meta_schema_id: int = Field(sa_type=BigInteger, description="主键")
    field_label: str = Field(max_length=50, description="字段标签")
    field_name: str = Field(max_length=50, description="字段列名")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")
    is_active: bool = Field(description="启用状态")
    sort_order: int = Field(description="排序权重")


class EnumFieldUpdate(SQLModel):
    """前端更新模型 - 用于接口请求"""

    field_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="主键")
    meta_schema_id: Optional[int] = Field(default=None, sa_type=BigInteger, description="主键")
    field_label: Optional[str] = Field(default=None, max_length=50, description="字段标签")
    field_name: Optional[str] = Field(default=None, max_length=50, description="字段列名")
    description: Optional[str] = Field(default=None, max_length=500, description="描述")
    is_active: Optional[bool] = Field(default=None, description="启用状态")
    sort_order: Optional[int] = Field(default=None, description="排序权重")


class EnumFieldResponse(BaseResponse):
    """前端响应模型 - 用于接口响应"""

    __database_schema__ = MetaConfig.SchemaName  # 仅用于内部处理
    field_id: int = Field(description="主键", sa_type=BigInteger)
    meta_schema_id: int = Field(description="主键", sa_type=BigInteger)
    field_label: str = Field(description="字段标签")
    field_name: str = Field(description="字段列名")
    description: Optional[str] = Field(description="描述", default=None)
    is_active: bool = Field(description="启用状态")
    sort_order: int = Field(description="排序权重")
    create_by: Optional[str] = Field(description="创建人", default=None)
    create_at: Optional[datetime] = Field(description="创建日期", default=None)
    update_by: Optional[str] = Field(description="修改人", default=None)
    update_at: Optional[datetime] = Field(description="修改日期", default=None)
