from ..meta.entity_class import EntityClass as EntityClass
from shudaodao_core import AsyncSession as AsyncSession

class GenericMetaService:
    def __new__(cls): ...
    async def initialize(self, db: AsyncSession = None): ...
    def get_metadata(self, schema_path, entity_path): ...
    def close(self) -> None: ...
    def __del__(self) -> None: ...
